@@ -18,7 +18,7 @@ our @Overridable;
 my @Prepend_parent;
 my %Recognized_Att_Keys;
 
-our $VERSION = '6.49_01';
+our $VERSION = '6.51_01';
 
 # Emulate something resembling CVS $Revision$
 (our $Revision = $VERSION) =~ s{_}{};
@@ -219,12 +219,14 @@ sub full_setup {
     my @attrib_help = qw/
 
     AUTHOR ABSTRACT ABSTRACT_FROM BINARY_LOCATION
-    C CAPI CCFLAGS CONFIG CONFIGURE DEFINE DIR DISTNAME DL_FUNCS DL_VARS
+    C CAPI CCFLAGS CONFIG CONFIGURE DEFINE DIR DISTNAME DISTVNAME
+    DL_FUNCS DL_VARS
     EXCLUDE_EXT EXE_FILES FIRST_MAKEFILE
     FULLPERL FULLPERLRUN FULLPERLRUNINST
     FUNCLIST H IMPORTS
 
-    INST_ARCHLIB INST_SCRIPT INST_BIN INST_LIB INST_MAN1DIR INST_MAN3DIR
+    INST_ARCHLIB INST_SCRIPT INST_BIN INST_LIB
+    INST_MAN1DIR INST_MAN3DIR INST_HTML1DIR INST_HTML3DIR
     INSTALLDIRS
     DESTDIR PREFIX INSTALL_BASE
     PERLPREFIX      SITEPREFIX      VENDORPREFIX
@@ -234,6 +236,9 @@ sub full_setup {
     INSTALLMAN1DIR          INSTALLMAN3DIR
     INSTALLSITEMAN1DIR      INSTALLSITEMAN3DIR
     INSTALLVENDORMAN1DIR    INSTALLVENDORMAN3DIR
+    INSTALLHTML1DIR          INSTALLHTML3DIR
+    INSTALLSITEHTML1DIR      INSTALLSITEHTML3DIR
+    INSTALLVENDORHTML1DIR    INSTALLVENDORHTML3DIR
     INSTALLSCRIPT   INSTALLSITESCRIPT  INSTALLVENDORSCRIPT
     PERL_LIB        PERL_ARCHLIB 
     SITELIBEXP      SITEARCHEXP 
@@ -243,7 +248,7 @@ sub full_setup {
     META_ADD META_MERGE MIN_PERL_VERSION
     MYEXTLIB NAME NEEDS_LINKING NOECHO NO_META NORECURS NO_VC OBJECT OPTIMIZE 
     PERL_MALLOC_OK PERL PERLMAINCC PERLRUN PERLRUNINST PERL_CORE
-    PERL_SRC PERM_RW PERM_RWX
+    PERL_SRC PERM_DIR PERM_RW PERM_RWX
     PL_FILES PM PM_FILTER PMLIBDIRS PMLIBPARENTDIRS POLLUTE PPM_INSTALL_EXEC
     PPM_INSTALL_SCRIPT PREREQ_FATAL PREREQ_PM PREREQ_PRINT PRINT_PREREQ
     SIGN SKIP TYPEMAPS VERSION VERSION_FROM XS XSOPT XSPROTOARG
@@ -281,7 +286,7 @@ sub full_setup {
  special_targets
  c_o xs_c xs_o
  top_targets blibdirs linkext dlsyms dynamic dynamic_bs
- dynamic_lib static static_lib manifypods processPL
+ dynamic_lib static static_lib manifypods htmlifypods processPL
  installbin subdirs
  clean_subdirs clean realclean_subdirs realclean 
  metafile signature
@@ -293,7 +298,7 @@ sub full_setup {
     @Overridable = @MM_Sections;
     push @Overridable, qw[
 
- libscan makeaperl needs_linking perm_rw perm_rwx
+ libscan makeaperl needs_linking
  subdir_x test_via_harness test_via_script 
 
  init_VERSION init_dist init_INST init_INSTALL init_DEST init_dirscan
@@ -340,8 +345,9 @@ sub full_setup {
     #
     @Prepend_parent = qw(
            INST_BIN INST_LIB INST_ARCHLIB INST_SCRIPT
-           MAP_TARGET INST_MAN1DIR INST_MAN3DIR PERL_SRC
-           PERL FULLPERL
+           MAP_TARGET INST_MAN1DIR INST_MAN3DIR
+           INST_HTML1DIR INST_HTML3DIR
+           PERL_SRC PERL FULLPERL
     );
 }
 
@@ -442,18 +448,22 @@ END
 
     my(%unsatisfied) = ();
     foreach my $prereq (sort keys %{$self->{PREREQ_PM}}) {
-        # 5.8.0 has a bug with require Foo::Bar alone in an eval, so an
-        # extra statement is a workaround.
         my $file = "$prereq.pm";
         $file =~ s{::}{/}g;
-        eval { require $file };
-
-        my $pr_version = $prereq->VERSION || 0;
+        my $path;
+        for my $dir (@INC) {
+            my $tmp = File::Spec->catfile($dir, $file);
+            if( -r $tmp ) {
+                $path = $tmp;
+                last;
+            }
+        }
+        my $pr_version = defined $path ? MM->parse_version($path) : 0;
 
         # convert X.Y_Z alpha version #s to X.YZ for easier comparisons
         $pr_version =~ s/(\d+)\.(\d+)_(\d+)/$1.$2$3/;
 
-        if ($@) {
+        if (!defined $path) {
             warn sprintf "Warning: prerequisite %s %s not found.\n", 
               $prereq, $self->{PREREQ_PM}{$prereq} 
                    unless $self->{PREREQ_FATAL};
@@ -570,30 +580,10 @@ END
     $self->init_linker;
     $self->init_ABSTRACT;
 
-    if (! $self->{PERL_SRC} ) {
-        require VMS::Filespec if $Is_VMS;
-        my($pthinks) = $self->canonpath($INC{'Config.pm'});
-        my($cthinks) = $self->catfile($Config{'archlibexp'},'Config.pm');
-        $pthinks = VMS::Filespec::vmsify($pthinks) if $Is_VMS;
-        if ($pthinks ne $cthinks &&
-            !($Is_Win32 and lc($pthinks) eq lc($cthinks))) {
-            print "Have $pthinks expected $cthinks\n";
-            if ($Is_Win32) {
-                $pthinks =~ s![/\\]Config\.pm$!!i; $pthinks =~ s!.*[/\\]!!;
-            }
-            else {
-                $pthinks =~ s!/Config\.pm$!!; $pthinks =~ s!.*/!!;
-            }
-            print STDOUT <<END unless $self->{UNINSTALLED_PERL};
-Your perl and your Config.pm seem to have different ideas about the 
-architecture they are running on.
-Perl thinks: [$pthinks]
-Config says: [$Config{archname}]
-This may or may not cause problems. Please check your installation of perl 
-if you have problems building this extension.
-END
-        }
-    }
+    $self->arch_check(
+        $INC{'Config.pm'},
+        $self->catfile($Config{'archlibexp'}, "Config.pm")
+    );
 
     $self->init_others();
     $self->init_platform();
@@ -1137,8 +1127,9 @@ want to specify some other option, set the C<TESTDB_SW> variable:
 =head2 make install
 
 make alone puts all relevant files into directories that are named by
-the macros INST_LIB, INST_ARCHLIB, INST_SCRIPT, INST_MAN1DIR and
-INST_MAN3DIR.  All these default to something below ./blib if you are
+the macros INST_LIB, INST_ARCHLIB, INST_SCRIPT, INST_BIN, INST_MAN1DIR,
+INST_MAN3DIR, INST_HTML1DIR and INST_HTML3DIR.
+All these default to something below ./blib if you are
 I<not> building below the perl source directory. If you I<are>
 building below the perl source, INST_LIB and INST_ARCHLIB default to
 ../../lib, and INST_SCRIPT is not defined.
@@ -1158,6 +1149,8 @@ INSTALLDIRS according to the following table:
   INST_SCRIPT    INSTALLSCRIPT   INSTALLSITESCRIPT   INSTALLVENDORSCRIPT
   INST_MAN1DIR   INSTALLMAN1DIR  INSTALLSITEMAN1DIR  INSTALLVENDORMAN1DIR
   INST_MAN3DIR   INSTALLMAN3DIR  INSTALLSITEMAN3DIR  INSTALLVENDORMAN3DIR
+  INST_HTML1DIR  INSTALLHTML1DIR INSTALLSITEHTML1DIR INSTALLVENDORHTML1DIR
+  INST_HTML3DIR  INSTALLHTML3DIR INSTALLSITEHTML3DIR INSTALLVENDORHTML3DIR
 
 The INSTALL... macros in turn default to their %Config
 ($Config{installprivlib}, $Config{installarchlib}, etc.) counterparts.
@@ -1732,6 +1725,14 @@ Directory to hold the man pages at 'make' time
 
 Directory to hold the man pages at 'make' time
 
+=item INST_HTML1DIR
+
+Directory to hold the html man pages at 'make' time
+
+=item INST_HTML3DIR
+
+Directory to hold the html man pages at 'make' time
+
 =item INST_SCRIPT
 
 Directory, where executable files should be installed during
@@ -1842,6 +1843,15 @@ EXE_FILES files that include POD directives. The files listed
 here will be converted to man pages and installed as was requested
 at Configure time.
 
+This hash should map POD files (or scripts containing POD) to the
+man file names under the C<blib/man1/> directory, as in the following
+example:
+
+  MAN1PODS            => {
+    'doc/command.pod'    => 'blib/man1/command.1',
+    'scripts/script.pl'  => 'blib/man1/script.1',
+  }
+
 =item MAN3PODS
 
 Hashref that assigns to *.pm and *.pod files the files into which the
@@ -1850,6 +1860,8 @@ for POD directives. Files that contain POD will be the default keys of
 the MAN3PODS hashref. These will then be converted to man pages during
 C<make> and will be installed during C<make install>.
 
+Example similar to MAN1PODS.
+
 =item MAP_TARGET
 
 If it is intended, that a new perl binary be produced, this variable
@@ -2016,15 +2028,17 @@ flags so perl can see the modules you're about to install.
 Directory containing the Perl source code (use of this should be
 avoided, it may be undefined)
 
+=item PERM_DIR
+
+Desired permission for directories. Defaults to C<755>.
+
 =item PERM_RW
 
 Desired permission for read/writable files. Defaults to C<644>.
-See also L<MM_Unix/perm_rw>.
 
 =item PERM_RWX
 
 Desired permission for executable files. Defaults to C<755>.
-See also L<MM_Unix/perm_rwx>.
 
 =item PL_FILES
 
